@@ -7,7 +7,7 @@
  */
 
 #ifndef SOURCE_VERSION
-#define SOURCE_VERSION			"2022.0"
+#define SOURCE_VERSION			"2022.1"
 #endif
 
 #include <net/ethernet.h>
@@ -31,7 +31,7 @@
 #define NO_FILTER			-1
 
 #define FIXED_TLV_LEN(__tlv_type) \
-	htons(sizeof(__tlv_type) - sizeof(__tlv_type.header))
+	htons(sizeof(__tlv_type) - sizeof((__tlv_type).header))
 
 enum data_source {
 	SOURCE_LOCAL = 0,
@@ -93,6 +93,7 @@ enum clientmode {
 	CLIENT_MODESWITCH,
 	CLIENT_CHANGE_INTERFACE,
 	CLIENT_CHANGE_BAT_IFACE,
+	CLIENT_SERVER_STATUS,
 };
 
 struct interface {
@@ -155,6 +156,7 @@ int alfred_client_set_data(struct globals *globals);
 int alfred_client_modeswitch(struct globals *globals);
 int alfred_client_change_interface(struct globals *globals);
 int alfred_client_change_bat_iface(struct globals *globals);
+int alfred_client_server_status(struct globals *globals);
 /* recv.c */
 int recv_alfred_packet(struct globals *globals, struct interface *interface,
 		       int recv_sock);
